@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,6 @@ package com.openexchange.unifiedinbox.utility;
 
 import static com.openexchange.mail.MailPath.SEPERATOR;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
-import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import gnu.trove.map.TIntObjectMap;
 import gnu.trove.map.hash.TIntObjectHashMap;
 import java.util.ArrayList;
@@ -62,9 +61,9 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.api.MailAccess;
+import com.openexchange.mailaccount.UnifiedInboxUID;
 import com.openexchange.unifiedinbox.UnifiedInboxAccess;
 import com.openexchange.unifiedinbox.UnifiedInboxException;
-import com.openexchange.unifiedinbox.UnifiedInboxUID;
 import com.openexchange.unifiedinbox.services.Services;
 
 /**
@@ -149,22 +148,7 @@ public final class UnifiedInboxUtility {
      * @throws OXException If specified nested full name is invalid
      */
     public static FullnameArgument parseNestedFullName(String nestedFullName) throws OXException {
-        // INBOX/default0/INBOX
-        if (!startsWithKnownFullname(nestedFullName)) {
-            throw UnifiedInboxException.Code.FOLDER_NOT_FOUND.create(prepareMailFolderParam(nestedFullName).getFullname());
-        }
-        // Cut off starting known full name and its separator character
-        final String fn = nestedFullName.substring(nestedFullName.indexOf(SEPERATOR) + 1);
-        return prepareMailFolderParam(fn);
-    }
-
-    private static boolean startsWithKnownFullname(String fullName) {
-        for (final String knownFullname : UnifiedInboxAccess.KNOWN_FOLDERS) {
-            if (fullName.startsWith(knownFullname)) {
-                return true;
-            }
-        }
-        return false;
+        return UnifiedInboxUID.parseNestedFullName(nestedFullName);
     }
 
     /**
